Index: wp-admin/includes/misc.php
===================================================================
--- wp-admin/includes/misc.php	(revision 16136)
+++ wp-admin/includes/misc.php	(working copy)
@@ -594,7 +594,7 @@
  */
 function admin_color_scheme_picker() {
 	global $_wp_admin_css_colors, $user_id; ?>
-<fieldset><legend class="screen-reader-text"><span><?php _e('Admin Color Scheme')?></span></legend>
+<fieldset><legend class="screen-reader-text"><span><?php _e('Dashboard Color Scheme')?></span></legend>
 <?php
 $current_color = get_user_option('admin_color', $user_id);
 if ( empty($current_color) )
Index: wp-admin/options-general.php
===================================================================
--- wp-admin/options-general.php	(revision 16136)
+++ wp-admin/options-general.php	(working copy)
@@ -103,7 +103,7 @@
 <tr valign="top">
 <th scope="row"><label for="admin_email"><?php _e('E-mail address') ?> </label></th>
 <td><input name="admin_email" type="text" id="admin_email" value="<?php form_option('admin_email'); ?>" class="regular-text" />
-<span class="description"><?php _e('This address is used for admin purposes, like new user notification.') ?></span></td>
+<span class="description"><?php _e('This address is used for administrative purposes, like new user notification.') ?></span></td>
 </tr>
 <tr valign="top">
 <th scope="row"><?php _e('Membership') ?></th>
@@ -122,12 +122,12 @@
 <tr valign="top">
 <th scope="row"><label for="new_admin_email"><?php _e('E-mail address') ?> </label></th>
 <td><input name="new_admin_email" type="text" id="new_admin_email" value="<?php form_option('admin_email'); ?>" class="regular-text code" />
-<span class="description"><?php _e('This address is used for admin purposes. If you change this we will send you an e-mail at your new address to confirm it. <strong>The new address will not become active until confirmed.</strong>') ?></span>
+<span class="description"><?php _e('This address is used for administrative purposes. If you change this we will send you an e-mail at your new address to confirm it. <strong>The new address will not become active until confirmed.</strong>') ?></span>
 <?php
 $new_admin_email = get_option( 'new_admin_email' );
 if ( $new_admin_email && $new_admin_email != get_option('admin_email') ) : ?>
 <div class="updated inline">
-<p><?php printf( __('There is a pending change of the admin e-mail to <code>%1$s</code>. <a href="%2$s">Cancel</a>'), $new_admin_email, esc_url( admin_url( 'options.php?dismiss=new_admin_email' ) ) ); ?></p>
+<p><?php printf( __('There is a pending change of the administrator e-mail to <code>%1$s</code>. <a href="%2$s">Cancel</a>'), $new_admin_email, esc_url( admin_url( 'options.php?dismiss=new_admin_email' ) ) ); ?></p>
 </div>
 <?php endif; ?>
 </td>
Index: wp-admin/themes.php
===================================================================
--- wp-admin/themes.php	(revision 16136)
+++ wp-admin/themes.php	(working copy)
@@ -188,7 +188,7 @@
 if ( current_user_can('edit_themes') && count( $broken_themes ) ) {
 ?>
 
-<h2><?php _e('Broken Themes'); ?> <?php if ( is_multisite() ) _e( '(Site admin only)' ); ?></h2>
+<h2><?php _e('Broken Themes'); ?> <?php if ( is_multisite() ) _e( '(Super administrator only)' ); ?></h2>
 <p><?php _e('The following themes are installed but incomplete. Themes must have a stylesheet and a template.'); ?></p>
 
 <table id="broken-themes">
Index: wp-app.php
===================================================================
--- wp-app.php	(revision 16136)
+++ wp-app.php	(working copy)
@@ -11,7 +11,7 @@
  * @var bool
  */
 define('APP_REQUEST', true);
-define('WP_SHOW_ADMIN_BAR' , false);
+define('WP_SHOW_ADMIN_BAR', false);
 
 /** Set up WordPress environment */
 require_once('./wp-load.php');
@@ -19,7 +19,7 @@
 /** Atom Publishing Protocol Class */
 require_once(ABSPATH . WPINC . '/atomlib.php');
 
-/** Admin Image API for metadata updating */
+/** Administration Image API for metadata updating */
 require_once(ABSPATH . '/wp-admin/includes/image.php');
 
 $_SERVER['PATH_INFO'] = preg_replace( '/.*\/wp-app\.php/', '', $_SERVER['REQUEST_URI'] );
@@ -285,7 +285,7 @@
 
 		// check to see if AtomPub is enabled
 		if ( !get_option( 'enable_app' ) )
-			$this->forbidden( sprintf( __( 'AtomPub services are disabled on this site.  An admin user can enable them at %s' ), admin_url('options-writing.php') ) );
+			$this->forbidden( sprintf( __( 'AtomPub services are disabled on this site.  An administrator user can enable them at %s' ), admin_url('options-writing.php') ) );
 
 		// dispatch
 		foreach ( $this->selectors as $regex => $funcs ) {
Index: wp-includes/js/tinymce/wp-mce-help.php
===================================================================
--- wp-includes/js/tinymce/wp-mce-help.php	(revision 16136)
+++ wp-includes/js/tinymce/wp-mce-help.php	(working copy)
@@ -184,7 +184,7 @@
 	<p><?php _e('<em>Rich editing</em>, also called WYSIWYG for What You See Is What You Get, means your text is formatted as you type. The rich editor creates HTML code behind the scenes while you concentrate on writing. Font styles, links and images all appear approximately as they will on the internet.') ?></p>
 	<p><?php _e('WordPress includes a rich HTML editor that works well in all major web browsers used today. However editing HTML is not the same as typing text. Each web page has two major components: the structure, which is the actual HTML code and is produced by the editor as you type, and the display, that is applied to it by the currently selected WordPress theme and is defined in style.css. WordPress is producing valid XHTML 1.0 which means that inserting multiple line breaks (BR tags) after a paragraph would not produce white space on the web page. The BR tags will be removed as invalid by the internal HTML correcting functions.') ?></p>
 	<p><?php _e('While using the editor, most basic keyboard shortcuts work like in any other text editor. For example: Shift+Enter inserts line break, Ctrl+C = copy, Ctrl+X = cut, Ctrl+Z = undo, Ctrl+Y = redo, Ctrl+A = select all, etc. (on Mac use the Command key instead of Ctrl). See the Hotkeys tab for all available keyboard shortcuts.') ?></p>
-    <p><?php _e('If you do not like the way the rich editor works, you may turn it off from Your Profile submenu, under Users in the admin menu.') ?></p>
+    <p><?php _e('If you do not like the way the rich editor works, you may turn it off from Your Profile submenu, under Users in the administration menu.') ?></p>
 </div>
 
 <div id="content2" class="hidden">
Index: xmlrpc.php
===================================================================
--- xmlrpc.php	(revision 16136)
+++ xmlrpc.php	(working copy)
@@ -11,7 +11,7 @@
  * @var bool
  */
 define('XMLRPC_REQUEST', true);
-define('WP_SHOW_ADMIN_BAR' , false);
+define('WP_SHOW_ADMIN_BAR', false);
 
 // Some browser-embedded clients send cookies. We don't want them.
 $_COOKIE = array();

Index: wp-admin/user-edit.php
===================================================================
--- wp-admin/user-edit.php	(revision 16136)
+++ wp-admin/user-edit.php	(working copy)
@@ -36,7 +36,7 @@
 else
 	$parent_file = 'profile.php';
 
 // contextual help - choose Help on the top right of admin panel to preview this.
 add_contextual_help($current_screen,
     '<p>' . __('Your profile contains information about you (your &#8220;account&#8221;) as well as some personal options related to using WordPress.') . '</p>' .
     '<p>' . __('You can change your password, turn on keyboard shortcuts, change the color scheme of your WordPress administration screens, and turn off the WYSIWYG (Visual) editor, among other things.') . '</p>' .
@@ -67,13 +67,13 @@
 ?>
 	<tr>
 		<th scope="row"><?php _e('Use https')?></th>
-		<td><label for="use_ssl"><input name="use_ssl" type="checkbox" id="use_ssl" value="1" <?php checked('1', $user->use_ssl); ?> /> <?php _e('Always use https when visiting the admin'); ?></label></td>
+		<td><label for="use_ssl"><input name="use_ssl" type="checkbox" id="use_ssl" value="1" <?php checked('1', $user->use_ssl); ?> /> <?php _e('Always use https when visiting the administration area.'); ?></label></td>
 	</tr>
 <?php
 }
 
 
-// Only allow super admins on multisite to edit every user.
+// Only allow super administrators on multisite to edit every user.
 if ( is_multisite() && ! current_user_can( 'manage_network_users' ) && $user_id != $current_user->ID && ! apply_filters( 'enable_edit_any_user_configuration', true ) )
 	wp_die( __( 'You do not have permission to edit this user.' ) );
 
@@ -162,7 +162,7 @@
 ?>
 
 <?php if ( !IS_PROFILE_PAGE && is_super_admin( $profileuser->ID ) && current_user_can( 'manage_network_options' ) ) { ?>
-	<div class="updated"><p><strong><?php _e('Important:'); ?></strong> <?php _e('This user has super admin privileges.'); ?></p></div>
+	<div class="updated"><p><strong><?php _e('Important:'); ?></strong> <?php _e('This user has super administrator privileges.'); ?></p></div>
 <?php } ?>
 <?php if ( isset($_GET['updated']) ) : ?>
 <div id="message" class="updated">
@@ -201,7 +201,7 @@
 <?php endif; ?>
 <?php if ( count($_wp_admin_css_colors) > 1 && has_action('admin_color_scheme_picker') ) : ?>
 <tr>
-<th scope="row"><?php _e('Admin Color Scheme')?></th>
+<th scope="row"><?php _e('Dashboard Color Scheme')?></th>
 <td><?php do_action( 'admin_color_scheme_picker' ); ?></td>
 </tr>
 <?php
@@ -249,7 +249,7 @@
 ?>
 </select>
 <?php if ( is_multisite() && is_network_admin() && current_user_can( 'manage_network_options' ) && !isset($super_admins) ) { ?>
-<p><label><input type="checkbox" id="super_admin" name="super_admin"<?php checked( is_super_admin( $profileuser->ID ) ); ?> /> <?php _e( 'Grant this user super admin privileges for the Network.'); ?></label></p>
+<p><label><input type="checkbox" id="super_admin" name="super_admin"<?php checked( is_super_admin( $profileuser->ID ) ); ?> /> <?php _e( 'Grant this user super administrator privileges for the Network.'); ?></label></p>
 <?php } ?>
 </td></tr>
 <?php endif; //!IS_PROFILE_PAGE ?>
@@ -36,7 +36,7 @@
 	$parent_file = 'profile.php';
 
-// contextual help - choose Help on the top right of admin panel to preview this.
+// contextual help - choose Help on the top right of administration panel to preview this.
 add_contextual_help($current_screen,
     '<p>' . __('Your profile contains information about you (your &#8220;account&#8221;) as well as some personal options related to using WordPress.') . '</p>' .